( cd usr/src ; rm -rf linux )
( cd usr/src ; ln -sf linux-1.1.94 linux )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf 3c509.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/3c509.c 3c509.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf 8390.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/8390.c 8390.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf 8390.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/8390.h 8390.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf LICENSE.SRC )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/LICENSE.SRC LICENSE.SRC )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf slhc.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/slhc.c slhc.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf README1.PLIP )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/README1.PLIP README1.PLIP )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf README2.PLIP )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/README2.PLIP README2.PLIP )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf Space.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/Space.c Space.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf auto_irq.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/auto_irq.c auto_irq.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf plip.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/plip.c plip.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf slip.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/slip.c slip.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf hp.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/hp.c hp.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf iow.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/iow.h iow.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf lance.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/lance.c lance.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf ne.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/ne.c ne.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf 3c501.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/3c501.c 3c501.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf slhc.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/slhc.h slhc.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf atp.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/atp.c atp.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf slip.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/slip.h slip.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf wd.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/wd.c wd.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf ppp.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/ppp.c ppp.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf 3c503.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/3c503.c 3c503.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf Makefile )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/Makefile Makefile )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf smc-ultra.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/smc-ultra.c smc-ultra.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf README.DLINK )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/README.DLINK README.DLINK )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf 3c503.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/3c503.h 3c503.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf eexpress.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/eexpress.c eexpress.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf skeleton.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/skeleton.c skeleton.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf CONFIG )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/CONFIG CONFIG )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf atp.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/atp.h atp.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf 3c507.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/3c507.c 3c507.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf at1700.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/at1700.c at1700.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf net_init.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/net_init.c net_init.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf depca.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/depca.h depca.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf depca.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/depca.c depca.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf loopback.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/loopback.c loopback.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf sk_g16.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/sk_g16.c sk_g16.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf sk_g16.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/sk_g16.h sk_g16.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf znet.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/znet.c znet.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf hp-plus.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/hp-plus.c hp-plus.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf ac3200.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/ac3200.c ac3200.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf 3c505dta.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/3c505dta.h 3c505dta.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf 3c505.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/3c505.c 3c505.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf README.3c505 )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/README.3c505 README.3c505 )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf 3c505.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/3c505.h 3c505.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf MODULES )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/MODULES MODULES )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf dummy.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/dummy.c dummy.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf de600.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/de600.c de600.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf e2100.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/e2100.c e2100.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf apricot.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/apricot.c apricot.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf de620.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/de620.c de620.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf de620.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/de620.h de620.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf ni52.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/ni52.c ni52.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf ni52.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/ni52.h ni52.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf ni65.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/ni65.c ni65.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf ni65.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/ni65.h ni65.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf ewrk3.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/ewrk3.c ewrk3.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf README.ewrk3 )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/README.ewrk3 README.ewrk3 )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf ewrk3.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/ewrk3.h ewrk3.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf arcnet.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/arcnet.c arcnet.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf tulip.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/tulip.c tulip.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf README.de4x5 )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/README.de4x5 README.de4x5 )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf de4x5.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/de4x5.c de4x5.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf de4x5.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/de4x5.h de4x5.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf README.wavelan )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/README.wavelan README.wavelan )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf i82586.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/i82586.h i82586.h )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf wavelan.c )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/wavelan.c wavelan.c )
( cd usr/src/linux-1.1.94/drivers/net ; rm -rf wavelan.h )
( cd usr/src/linux-1.1.94/drivers/net ; ln -sf /cdrom/live/usr/src/linux/drivers/net/wavelan.h wavelan.h )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf hd.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/hd.c hd.c )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf ll_rw_blk.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/ll_rw_blk.c ll_rw_blk.c )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf floppy.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/floppy.c floppy.c )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf Makefile )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/Makefile Makefile )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf blk.h )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/blk.h blk.h )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf ramdisk.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/ramdisk.c ramdisk.c )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf genhd.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/genhd.c genhd.c )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf xd.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/xd.c xd.c )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf cdu31a.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/cdu31a.c cdu31a.c )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf mcd.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/mcd.c mcd.c )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf sbpcd.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/sbpcd.c sbpcd.c )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf README.sbpcd )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/README.sbpcd README.sbpcd )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf README.hd )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/README.hd README.hd )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf README.ide )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/README.ide README.ide )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf ide.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/ide.c ide.c )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf MAKEDEV.ide1 )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/MAKEDEV.ide1 MAKEDEV.ide1 )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf ide-cd.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/ide-cd.c ide-cd.c )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf sbpcd2.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/sbpcd2.c sbpcd2.c )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf sbpcd3.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/sbpcd3.c sbpcd3.c )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf sbpcd4.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/sbpcd4.c sbpcd4.c )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf README.aztcd )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/README.aztcd README.aztcd )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf aztcd.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/aztcd.c aztcd.c )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf README.fd )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/README.fd README.fd )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf README.sonycd535 )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/README.sonycd535 README.sonycd535 )
( cd usr/src/linux-1.1.94/drivers/block ; rm -rf sonycd535.c )
( cd usr/src/linux-1.1.94/drivers/block ; ln -sf /cdrom/live/usr/src/linux/drivers/block/sonycd535.c sonycd535.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf keyboard.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/keyboard.c keyboard.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf Makefile )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/Makefile Makefile )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf console.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/console.c console.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf tty_ioctl.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/tty_ioctl.c tty_ioctl.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf tty_io.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/tty_io.c tty_io.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf pty.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/pty.c pty.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf mouse.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/mouse.c mouse.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf lp.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/lp.c lp.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf mem.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/mem.c mem.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf busmouse.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/busmouse.c busmouse.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf vt_kern.h )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/vt_kern.h vt_kern.h )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf vt.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/vt.c vt.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf psaux.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/psaux.c psaux.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf atixlmouse.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/atixlmouse.c atixlmouse.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf msbusmouse.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/msbusmouse.c msbusmouse.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf serial.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/serial.c serial.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf tpqic02.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/tpqic02.c tpqic02.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf defkeymap.map )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/defkeymap.map defkeymap.map )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf defkeymap.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/defkeymap.c defkeymap.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf diacr.h )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/diacr.h diacr.h )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf kbd_kern.h )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/kbd_kern.h kbd_kern.h )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf n_tty.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/n_tty.c n_tty.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf ChangeLog )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/ChangeLog ChangeLog )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf uni_to_437.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/uni_to_437.c uni_to_437.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf cyclades.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/cyclades.c cyclades.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf vesa_blank.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/vesa_blank.c vesa_blank.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf consolemap.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/consolemap.c consolemap.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf consolemap.h )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/consolemap.h consolemap.h )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf selection.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/selection.c selection.c )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf selection.h )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/selection.h selection.h )
( cd usr/src/linux-1.1.94/drivers/char ; rm -rf vc_screen.c )
( cd usr/src/linux-1.1.94/drivers/char ; ln -sf /cdrom/live/usr/src/linux/drivers/char/vc_screen.c vc_screen.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf Makefile )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/Makefile Makefile )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf aha1542.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/aha1542.c aha1542.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf aha1542.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/aha1542.h aha1542.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf aha1740.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/aha1740.c aha1740.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf aha1740.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/aha1740.h aha1740.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf fdomain.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/fdomain.c fdomain.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf hosts.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/hosts.c hosts.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf hosts.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/hosts.h hosts.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf scsi.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/scsi.c scsi.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf scsi.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/scsi.h scsi.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf scsi_debug.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/scsi_debug.c scsi_debug.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf scsi_debug.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/scsi_debug.h scsi_debug.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf scsi_ioctl.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/scsi_ioctl.c scsi_ioctl.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf scsi_ioctl.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/scsi_ioctl.h scsi_ioctl.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf sd.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/sd.c sd.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf sd.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/sd.h sd.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf sd_ioctl.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/sd_ioctl.c sd_ioctl.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf seagate.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/seagate.c seagate.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf seagate.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/seagate.h seagate.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf sr.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/sr.c sr.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf sr.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/sr.h sr.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf sr_ioctl.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/sr_ioctl.c sr_ioctl.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf st.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/st.c st.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf st.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/st.h st.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf ultrastor.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/ultrastor.c ultrastor.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf ultrastor.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/ultrastor.h ultrastor.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf wd7000.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/wd7000.c wd7000.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf wd7000.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/wd7000.h wd7000.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf constants.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/constants.c constants.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf constants.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/constants.h constants.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf pas16.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/pas16.c pas16.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf NCR5380.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/NCR5380.c NCR5380.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf aha152x.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/aha152x.h aha152x.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf NCR5380.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/NCR5380.h NCR5380.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf pas16.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/pas16.h pas16.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf aha152x.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/aha152x.c aha152x.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf g_NCR5380.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/g_NCR5380.c g_NCR5380.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf g_NCR5380.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/g_NCR5380.h g_NCR5380.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf sg.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/sg.c sg.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf sg.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/sg.h sg.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf t128.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/t128.c t128.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf t128.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/t128.h t128.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf fdomain.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/fdomain.h fdomain.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf README.st )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/README.st README.st )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf ChangeLog )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/ChangeLog ChangeLog )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf buslogic.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/buslogic.c buslogic.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf buslogic.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/buslogic.h buslogic.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf 53c7,8xx.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/53c7,8xx.c 53c7,8xx.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf 53c7,8xx.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/53c7,8xx.h 53c7,8xx.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf 53c7,8xx.scr )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/53c7,8xx.scr 53c7,8xx.scr )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf 53c8xx_d.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/53c8xx_d.h 53c8xx_d.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf 53c8xx_u.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/53c8xx_u.h 53c8xx_u.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf script_asm.pl )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/script_asm.pl script_asm.pl )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf scsicam.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/scsicam.c scsicam.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf eata.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/eata.c eata.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf README.aha274x )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/README.aha274x README.aha274x )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf eata.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/eata.h eata.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf aha274x.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/aha274x.c aha274x.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf in2000.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/in2000.c in2000.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf aha274x.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/aha274x.h aha274x.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf u14-34f.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/u14-34f.c u14-34f.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf aha274x.seq )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/aha274x.seq aha274x.seq )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf README.qlogic )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/README.qlogic README.qlogic )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf aha274x_seq.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/aha274x_seq.h aha274x_seq.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf u14-34f.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/u14-34f.h u14-34f.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf aic7770.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/aic7770.c aic7770.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf in2000.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/in2000.h in2000.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf qlogic.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/qlogic.c qlogic.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf scsi_module.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/scsi_module.c scsi_module.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf qlogic.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/qlogic.h qlogic.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf eata_dma.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/eata_dma.c eata_dma.c )
( cd usr/src/linux-1.1.94/drivers/scsi ; rm -rf eata_dma.h )
( cd usr/src/linux-1.1.94/drivers/scsi ; ln -sf /cdrom/live/usr/src/linux/drivers/scsi/eata_dma.h eata_dma.h )
( cd usr/src/linux-1.1.94/drivers ; rm -rf Makefile )
( cd usr/src/linux-1.1.94/drivers ; ln -sf /cdrom/live/usr/src/linux/drivers/Makefile Makefile )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf CHANGELOG )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/CHANGELOG CHANGELOG )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf COPYING )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/COPYING COPYING )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf Makefile )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/Makefile Makefile )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf Readme )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/Readme Readme )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf Readme.linux )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/Readme.linux Readme.linux )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf adlib_card.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/adlib_card.c adlib_card.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf audio.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/audio.c audio.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf configure.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/configure.c configure.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf dev_table.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/dev_table.c dev_table.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf dev_table.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/dev_table.h dev_table.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf ad1848.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/ad1848.c ad1848.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf dmabuf.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/dmabuf.c dmabuf.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf finetune.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/finetune.h finetune.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf gus_card.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/gus_card.c gus_card.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf gus_hw.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/gus_hw.h gus_hw.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf gus_linearvol.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/gus_linearvol.h gus_linearvol.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf gus_midi.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/gus_midi.c gus_midi.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf gus_vol.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/gus_vol.c gus_vol.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf gus_wave.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/gus_wave.c gus_wave.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf ics2101.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/ics2101.c ics2101.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf midibuf.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/midibuf.c midibuf.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf mpu401.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/mpu401.c mpu401.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf opl3.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/opl3.c opl3.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf opl3.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/opl3.h opl3.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf os.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/os.h os.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf pas.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/pas.h pas.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf pas2_card.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/pas2_card.c pas2_card.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf pas2_midi.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/pas2_midi.c pas2_midi.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf pas2_mixer.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/pas2_mixer.c pas2_mixer.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf pas2_pcm.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/pas2_pcm.c pas2_pcm.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf patmgr.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/patmgr.c patmgr.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf sb.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/sb.h sb.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf sb16_dsp.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/sb16_dsp.c sb16_dsp.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf sb16_midi.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/sb16_midi.c sb16_midi.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf sb_card.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/sb_card.c sb_card.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf sb_dsp.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/sb_dsp.c sb_dsp.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf sb_midi.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/sb_midi.c sb_midi.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf sb_mixer.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/sb_mixer.c sb_mixer.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf sb_mixer.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/sb_mixer.h sb_mixer.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf sequencer.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/sequencer.c sequencer.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf sound_calls.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/sound_calls.h sound_calls.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf sound_config.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/sound_config.h sound_config.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf sound_switch.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/sound_switch.c sound_switch.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf soundcard.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/soundcard.c soundcard.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf tuning.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/tuning.h tuning.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf ulaw.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/ulaw.h ulaw.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf midi_synth.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/midi_synth.c midi_synth.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf pss.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/pss.c pss.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf sound_timer.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/sound_timer.c sound_timer.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf sys_timer.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/sys_timer.c sys_timer.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf uart6850.c )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/uart6850.c uart6850.c )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf midi_ctrl.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/midi_ctrl.h midi_ctrl.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf midi_synth.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/midi_synth.h midi_synth.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf pss.h )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/pss.h pss.h )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf Readme.v30 )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/Readme.v30 Readme.v30 )
( cd usr/src/linux-1.1.94/drivers/sound ; rm -rf experimental.txt )
( cd usr/src/linux-1.1.94/drivers/sound ; ln -sf /cdrom/live/usr/src/linux/drivers/sound/experimental.txt experimental.txt )
